@@ -1,5 +1,7 @@
 import sys
-from smallscheme.scheme import *
+from smallscheme.dtypes import *
+from smallscheme.parse import parse_str
+from smallscheme.scheme import evalu, printable_value
 from smallscheme.test_util import teq
 
 def test_evalu():
